# -*- coding: utf-8 -*-
#
# Copyright 2017 Ricequant, Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


PUBLIC_FUND_COMMISSION = {
    'Hybrid': {
        'Buy': 0.015,
        'Sell': 0.005
    },
    'Stock': {
        'Buy': 0.015,
        'Sell': 0.005
    },
    'Bond': {
        'Buy': 0.006,
        'Sell': 0.005
    },
    'StockIndex': {
        'Buy': 0.01,
        'Sell': 0.005
    },
    'BondIndex': {
        'Buy': 0.01,
        'Sell': 0.005
    },
    'QDII': {
        'Buy': 0.015,
        'Sell': 0.005
    },
    'Other': {
        'Buy': 0,
        'Sell': 0
    },
    'Related': {
        'Buy': 0,
        'Sell': 0
    },
}



# -*- coding: utf-8 -*-
#
# Copyright 2017 Ricequant, Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .cash_validator import CashValidator
from .is_trading_validator import IsTradingValidator
from .price_validator import PriceValidator
from .stock_position_validator import StockPositionValidator
from .future_position_validator import FuturePositionValidator
from .self_trade_validator import SelfTradeValidator

__all__ = [
    "CashValidator",
    "StockPositionValidator",
    "FuturePositionValidator",
    "PriceValidator",
    "IsTradingValidator",
    "SelfTradeValidator",
]
